/*-----------------------------------------------------------------------------
| Variables
|----------------------------------------------------------------------------*/

:root {
    --jp-flat-button-height: 24px;
    --jp-flat-button-padding: 8px 12px;
  }
  
  /*-----------------------------------------------------------------------------
  | Copyright (c) Jupyter Development Team.
  | Distributed under the terms of the Modified BSD License.
  |----------------------------------------------------------------------------*/
  
  button {
    border-radius: var(--jp-border-radius);
  }
  
  button:focus-visible {
    border: 1px solid var(--md-blue-900);
  }
  
  button.jp-mod-styled.jp-mod-accept {
    background: var(--md-blue-700);
    border: 0;
    color: white;
  }
  
  button.jp-mod-styled.jp-mod-accept:hover {
    background: var(--md-blue-800);
  }
  
  button.jp-mod-styled.jp-mod-accept:active {
    background: var(--md-blue-900);
  }
  
  button.jp-mod-styled.jp-mod-accept:focus-visible {
    border: 1px solid var(--md-blue-900);
  }
  
  button.jp-mod-styled.jp-mod-reject {
    background: var(--md-grey-600);
    border: 0;
    color: white;
  }
  
  button.jp-mod-styled.jp-mod-reject:hover {
    background: var(--md-grey-700);
  }
  
  button.jp-mod-styled.jp-mod-reject:active {
    background: var(--md-grey-800);
  }
  
  button.jp-mod-styled.jp-mod-reject:focus-visible {
    border: 1px solid var(--md-grey-800);
  }
  
  button.jp-mod-styled.jp-mod-warn {
    background: var(--md-red-700);
    border: 0;
    color: white;
  }
  
  button.jp-mod-styled.jp-mod-warn:hover {
    background: var(--md-red-800);
  }
  
  button.jp-mod-styled.jp-mod-warn:active {
    background: var(--md-red-900);
  }
  
  button.jp-mod-styled.jp-mod-warn:focus-visible {
    border: 1px solid var(--md-red-900);
  }
  
  .jp-Button-flat {
    text-decoration: none;
    padding: var(--jp-flat-button-padding);
    color: var(--md-grey-600);
    font-weight: 500;
    background-color: transparent;
    height: var(--jp-private-running-shutdown-button-height);
    line-height: var(--jp-private-running-shutdown-button-height);
    transition: background-color 0.1s ease;
    border-radius: 2px;
  }
  
  .jp-Button-flat:hover {
    background-color: var(--md-grey-700);
  }
  
  .jp-Button-flat:focus {
    border: none;
    box-shadow: none;
    background-color: var(--md-grey-800);
  }
  